package com.srs.dormitory.domain;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;

import java.io.Serializable;
import java.time.LocalDateTime;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * <p>
 * 维修记录表
 * </p>
 *
 * @author 猪油骨
 * @since 2023-08-04
 */
@Data
@TableName("dms_repair_records")
@ApiModel(value = "DmsRepairRecords对象", description = "维修记录表")
public class DmsRepairRecords implements Serializable {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty("记录ID，主键")
    @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    @ApiModelProperty("用户ID，外键，关联到用户表")
    @TableField("tech_name")
    private String techName;

    @ApiModelProperty("学生ID，外键，关联到学生表")
    @TableField("stu_no")
    private String stuNo;

    @ApiModelProperty("宿舍ID，外键，关联到宿舍表")
    @TableField("dorm_id")
    private Long dormId;

    @ApiModelProperty("维修单号")
    @TableField("repair_number")
    private String repairNumber;

    @ApiModelProperty("期望上门维修时间")
    @TableField("expected_visit_time")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime expectedVisitTime;

    @ApiModelProperty("报修内容")
    @TableField("content")
    private String content;

    @ApiModelProperty("维修内容描述")
    @TableField("description")
    private String description;

    @ApiModelProperty("报修状态，0:等待管理员审核，1:管理员审核通过已分配师傅等待上门维修，2:维修完成，3:等待评价，4:已评价，-1:取消维修，-2:维修师傅申请转单,-3:审核不通过")
    @TableField("status")
    private String status;
    @ApiModelProperty("审核人")
    @TableField("auditors")
    private String auditors;
    @ApiModelProperty("取消理由")
    @TableField("reason")
    private String reason;

    @ApiModelProperty("分配时间")
    @TableField("assign_time")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime assignTime;

    @ApiModelProperty("维修时间")
    @TableField("fix_time")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime fixTime;

    @ApiModelProperty("满意度评分")
    @TableField("satisfaction")
    private Integer satisfaction;
    @ApiModelProperty("评价")
    @TableField("appraise")
    private String appraise;


    @ApiModelProperty("创建时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @TableField(value = "create_time", fill = FieldFill.INSERT)
    private LocalDateTime createTime;

    @ApiModelProperty("修改时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @TableField(value = "update_time", fill = FieldFill.INSERT_UPDATE)
    private LocalDateTime updateTime;


}




