package com.srs.web.controller.comprehensive;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.srs.comprehensive.domain.Questionnaire;
import com.srs.comprehensive.service.IQuestionnaireService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import io.swagger.annotations.*;
import org.springframework.security.access.prepost.PreAuthorize;

import com.srs.common.core.controller.BaseController;
import com.srs.common.core.domain.AjaxResult;
import com.srs.common.utils.poi.ExcelUtil;
import com.srs.common.enums.BusinessType;
import com.srs.common.annotation.Log;
import com.srs.common.core.page.TableDataInfo;

/**
 * 问卷调查Controller
 *
 * @author srs
 * @date 2024-05-18
 */
@RestController
@RequestMapping("/comprehensive/questionnaire")
@Api(value = "问卷调查管理", tags = "问卷调查管理")
public class QuestionnaireController extends BaseController {
    @Autowired
    private IQuestionnaireService questionnaireService;

    /**
     * 查询问卷调查列表
     */
//@PreAuthorize("@ss.hasPermi('system:questionnaire:list')")
    @GetMapping("/list")
    @ApiOperation("查询问卷调查列表")
    public TableDataInfo list(Questionnaire questionnaire)
    {
        startPage();
        List<Questionnaire> list = questionnaireService.selectQuestionnaireList(questionnaire);
        return getDataTable(list);
    }

    /**
     * 导出问卷调查列表
     */
//    @PreAuthorize("@ss.hasPermi('system:questionnaire:export')")
    @Log(title = "问卷调查", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation("导出问卷调查列表")
    public void export(HttpServletResponse response, Questionnaire questionnaire)
    {
        List<Questionnaire> list = questionnaireService.selectQuestionnaireList(questionnaire);
        ExcelUtil<Questionnaire> util = new ExcelUtil<Questionnaire>(Questionnaire.class);
        util.exportExcel(response, list, "问卷调查数据");
    }

    /**
     * 获取问卷调查详细信息
     */
//    @PreAuthorize("@ss.hasPermi('system:questionnaire:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取问卷调查详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(questionnaireService.selectQuestionnaireById(id));
    }

    /**
     * 新增问卷调查
     */
//    @PreAuthorize("@ss.hasPermi('system:questionnaire:add')")
    @Log(title = "问卷调查", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ApiOperation("新增问卷调查")
    public AjaxResult add(@RequestBody Questionnaire questionnaire)
    {
      questionnaireService.insertQuestionnaire(questionnaire);
        return AjaxResult.success(questionnaire);
    }

//    @Log(title = "问卷调查", businessType = BusinessType.INSERT)
    @PostMapping("/saveAndRelease")
    @ApiOperation("保存并且发布")
    public AjaxResult saveAndRelease(@RequestBody Questionnaire questionnaire)
    {
        int result = 0;
        if(questionnaire.getId() != null){
            // 更新再发布
            result =  questionnaireService.updateAndRelease(questionnaire);

        }else{
            //保存子
            result = questionnaireService.saveAndRelease(questionnaire);

        }

        return AjaxResult.success(questionnaire);
    }

    /**
     * 修改问卷调查
     */
//    @PreAuthorize("@ss.hasPermi('system:questionnaire:edit')")
    @Log(title = "问卷调查", businessType = BusinessType.UPDATE)
    @PostMapping("/update")
    @ApiOperation("修改问卷调查")
    public AjaxResult edit(@RequestBody Questionnaire questionnaire)
    {
        questionnaireService.updateQuestionnaire(questionnaire);
        return  AjaxResult.success(questionnaire);
    }

    /**
     * 删除问卷调查
     */
//    @PreAuthorize("@ss.hasPermi('system:questionnaire:remove')")
    @Log(title = "问卷调查", businessType = BusinessType.DELETE)
    @PostMapping("/{ids}")
    @ApiOperation("删除问卷调查")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(questionnaireService.deleteQuestionnaireByIds(ids));
    }

    /**
     * 发布问卷调查
     * @param questionnaire
     * @return
     */

    @PostMapping("/release")
    public AjaxResult release(@RequestBody Questionnaire questionnaire)
    {

        Long deptId = getDeptId();
        System.out.println(deptId);

        return toAjax(questionnaireService.release(questionnaire));
    }

    @PostMapping("/releaseNew")
    public AjaxResult releaseNew(@RequestBody Questionnaire questionnaire)
    {

        questionnaire.setStatus("1");
        return toAjax(questionnaireService.releaseNew(questionnaire));
    }

    @PostMapping("/releaseStop")
    public AjaxResult releaseStop(@RequestBody Questionnaire questionnaire)
    {

        questionnaire.setStatus("0");
        return toAjax(questionnaireService.releaseNew(questionnaire));
    }




}
