package com.srs.web.controller.system;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.srs.common.core.domain.model.LoginUser;
import com.srs.comprehensive.service.ISrsStudentService;
import com.srs.framework.web.service.TokenService;
import com.srs.stureg.domain.SrsStuReg;
import com.srs.stureg.domain.SrsStuTodo;
import com.srs.stureg.mapper.SrsStuTodoMapper;
import com.srs.stureg.service.ISrsStuRegService;
import com.srs.stureg.service.ISrsStuTodoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.ArrayUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import com.srs.common.annotation.Log;
import com.srs.common.core.controller.BaseController;
import com.srs.common.core.domain.AjaxResult;
import com.srs.common.core.domain.entity.SysDept;
import com.srs.common.core.domain.entity.SysRole;
import com.srs.common.core.domain.entity.SysUser;
import com.srs.common.core.page.TableDataInfo;
import com.srs.common.enums.BusinessType;
import com.srs.common.utils.SecurityUtils;
import com.srs.common.utils.StringUtils;
import com.srs.common.utils.poi.ExcelUtil;
import com.srs.system.service.ISysDeptService;
import com.srs.system.service.ISysPostService;
import com.srs.system.service.ISysRoleService;
import com.srs.system.service.ISysUserService;

/**
 * 用户信息
 *
 * @author srs
 */
@Api(tags = "用户信息")
@RestController
@RequestMapping("/system/user")
public class SysUserController extends BaseController
{
    @Autowired
    private ISysUserService userService;

    @Autowired
    private ISysRoleService roleService;

    @Autowired
    private ISysDeptService deptService;

    @Autowired
    private ISysPostService postService;
    //待办
    @Autowired
    private ISrsStuTodoService iSrsStuTodoService;
    //新生信息
    @Autowired
    private ISrsStuRegService iSrsStuRegService;
    @Autowired
    private TokenService tokenService;

    @Autowired
    private ISrsStudentService srsStudentService;

    /**
     * 获取用户列表
     */
    @PreAuthorize("@ss.hasPermi('system:user:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysUser user)
    {
        startPage();
        List<SysUser> list = userService.selectUserList(user);
        return getDataTable(list);
    }

    @Log(title = "用户管理", businessType = BusinessType.EXPORT)
    @PreAuthorize("@ss.hasPermi('system:user:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysUser user)
    {
        List<SysUser> list = userService.selectUserList(user);
        ExcelUtil<SysUser> util = new ExcelUtil<SysUser>(SysUser.class);
        util.exportExcel(response, list, "用户数据");
    }

    @Log(title = "用户管理", businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('system:user:import')")
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws Exception
    {
        ExcelUtil<SysUser> util = new ExcelUtil<SysUser>(SysUser.class);
        List<SysUser> userList = util.importExcel(file.getInputStream());
        String operName = getUsername();
        String message = userService.importUser(userList, updateSupport, operName);
        return success(message);
    }

    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<SysUser> util = new ExcelUtil<SysUser>(SysUser.class);
        util.importTemplateExcel(response, "用户数据");
    }

    /**
     * 根据用户编号获取详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:user:query')")
    @GetMapping(value = { "/", "/{userId}" })
    public AjaxResult getInfo(@PathVariable(value = "userId", required = false) Long userId)
    {
        userService.checkUserDataScope(userId);
        AjaxResult ajax = AjaxResult.success();
        List<SysRole> roles = roleService.selectRoleAll();
        //去掉只有管理员才显示所有角色
        ajax.put("roles", roles);//SysUser.isAdmin(userId) ? roles : roles.stream().filter(r -> !r.isAdmin()).collect(Collectors.toList()));
        ajax.put("posts", postService.selectPostAll());
        if (StringUtils.isNotNull(userId))
        {
            SysUser sysUser = userService.selectUserById(userId);
            ajax.put(AjaxResult.DATA_TAG, sysUser);
            ajax.put("postIds", postService.selectPostListByUserId(userId));
            ajax.put("roleIds", sysUser.getRoles().stream().map(SysRole::getRoleId).collect(Collectors.toList()));
        }
        return ajax;
    }

    /**
     * 新增用户
     */
    @PreAuthorize("@ss.hasPermi('system:user:add')")
    @Log(title = "用户管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody SysUser user)
    {
        if (!userService.checkUserNameUnique(user))
        {
            return error("新增用户'" + user.getUserName() + "'失败，登录账号已存在");
        }
        else if (StringUtils.isNotEmpty(user.getPhonenumber()) && !userService.checkPhoneUnique(user))
        {
            return error("新增用户'" + user.getUserName() + "'失败，手机号码已存在");
        }
        else if (StringUtils.isNotEmpty(user.getEmail()) && !userService.checkEmailUnique(user))
        {
            return error("新增用户'" + user.getUserName() + "'失败，邮箱账号已存在");
        }
        user.setCreateBy(getUsername());
        user.setPassword(SecurityUtils.encryptPassword(user.getPassword()));
        return toAjax(userService.insertUser(user));
    }

    /**
     * 修改用户
     */
    @PreAuthorize("@ss.hasPermi('system:user:edit')")
    @Log(title = "用户管理", businessType = BusinessType.UPDATE)
    @PostMapping("/update")
    public AjaxResult edit(@Validated @RequestBody SysUser user)
    {
        userService.checkUserAllowed(user);
        userService.checkUserDataScope(user.getUserId());
        if (!userService.checkUserNameUnique(user))
        {
            return error("修改用户'" + user.getUserName() + "'失败，登录账号已存在");
        }
        else if (StringUtils.isNotEmpty(user.getPhonenumber()) && !userService.checkPhoneUnique(user))
        {
            return error("修改用户'" + user.getUserName() + "'失败，手机号码已存在");
        }
        else if (StringUtils.isNotEmpty(user.getEmail()) && !userService.checkEmailUnique(user))
        {
            return error("修改用户'" + user.getUserName() + "'失败，邮箱账号已存在");
        }
        user.setUpdateBy(getUsername());
        return toAjax(userService.updateUser(user));
    }

    /**
     * 删除用户
     */
    @PreAuthorize("@ss.hasPermi('system:user:remove')")
    @Log(title = "用户管理", businessType = BusinessType.DELETE)
    @PostMapping("/delete/{userIds}")
    public AjaxResult remove(@PathVariable Long[] userIds)
    {
        if (ArrayUtils.contains(userIds, getUserId()))
        {
            return error("当前用户不能删除");
        }
        return toAjax(userService.deleteUserByIds(userIds));
    }

    /**
     * 重置密码
     */
    @PreAuthorize("@ss.hasPermi('system:user:resetPwd')")
    @Log(title = "用户管理", businessType = BusinessType.UPDATE)
    @PostMapping("/resetPwd/update")
    public AjaxResult resetPwd(@RequestBody SysUser user)
    {
        userService.checkUserAllowed(user);
        userService.checkUserDataScope(user.getUserId());
        user.setPassword(SecurityUtils.encryptPassword(user.getPassword()));
        user.setUpdateBy(getUsername());
        return toAjax(userService.resetPwd(user));
    }

    @Log(title = "用户管理", businessType = BusinessType.UPDATE)
    @PostMapping("/resetPwdUpdate")
    public AjaxResult resetUserPwd(@RequestBody Map<String,Object> sysUserPwd)
    {
        SysUser sysUser = new SysUser();
        sysUser.setUserId(getUserId());
        sysUser.setPassword(SecurityUtils.encryptPassword(sysUserPwd.get("pwd").toString()));
        sysUser.setUpdateBy(getUsername());
        SrsStuReg ownInfoByKsh = iSrsStuRegService.getOwnInfoByKsh(getUsername());//考生号查询学号
        SrsStuTodo srsStuTodo = new SrsStuTodo();
        srsStuTodo.setStuNo(ownInfoByKsh.getXH());
//        List<SrsStuTodo> srsStuTodos = iSrsStuTodoService.selectSrsStuTodoList(srsStuTodo);//查询待办
        int i = userService.resetPwd(sysUser);//修改密码
        if (i>0) {
            SrsStuReg stu = new SrsStuReg();
            stu.setKSH(getUsername());
            int res = iSrsStuRegService.changePwdIs(stu);
            return toAjax(res);
//            for (SrsStuTodo scaled_PARAMcause : srsStuTodos) {
//                if (scaled_PARAMcause.getTaskId() == 3) {
//                    scaled_PARAMcause.setStatus("1");
//                    int i1 = iSrsStuTodoService.updateSrsStuTodo(scaled_PARAMcause);
//                    if (i1>0){
//                        return toAjax(1);
//                    }
//                }
//            }
        }
        return toAjax(0);
    }



    /**
     * 状态修改
     */
    @PreAuthorize("@ss.hasPermi('system:user:edit')")
    @Log(title = "用户管理", businessType = BusinessType.UPDATE)
    @PostMapping("/changeStatus/update")
    public AjaxResult changeStatus(@RequestBody SysUser user)
    {
        userService.checkUserAllowed(user);
        userService.checkUserDataScope(user.getUserId());
        user.setUpdateBy(getUsername());
        return toAjax(userService.updateUserStatus(user));
    }

    /**
     * 根据用户编号获取授权角色
     */
    @PreAuthorize("@ss.hasPermi('system:user:query')")
    @GetMapping("/authRole/{userId}")
    public AjaxResult authRole(@PathVariable("userId") Long userId)
    {
        AjaxResult ajax = AjaxResult.success();
        SysUser user = userService.selectUserById(userId);
        List<SysRole> roles = roleService.selectRolesByUserId(userId);
        ajax.put("user", user);
        //去掉只有管理员才显示所有角色
        ajax.put("roles", roles);//SysUser.isAdmin(userId) ? roles : roles.stream().filter(r -> !r.isAdmin()).collect(Collectors.toList()));
        return ajax;
    }

    /**
     * 用户授权角色
     */
    @PreAuthorize("@ss.hasPermi('system:user:edit')")
    @Log(title = "用户管理", businessType = BusinessType.GRANT)
    @PostMapping("/authRole/update")
    public AjaxResult insertAuthRole(Long userId, Long[] roleIds)
    {
        userService.checkUserDataScope(userId);
        userService.insertUserAuth(userId, roleIds);
        return success();
    }

    /**
     * 获取部门树列表
     */
   // @PreAuthorize("@ss.hasPermi('system:user:list')")
    @GetMapping("/deptTree")
    public AjaxResult deptTree(SysDept dept)
    {
        return success(deptService.selectDeptTreeList(dept));
    }

    /**
     * 更新签名
     */
//    @PreAuthorize("@ss.hasPermi('system:user:list')")
    @PostMapping("/updateSignature")
    public AjaxResult updateSignature(@RequestBody SysUser sysUser)
    {

        String username = getUsername();
        sysUser.setUserName(username);
        int i = userService.updateSignature(sysUser);
        if(i > 0){
            LoginUser loginUser = getLoginUser();
            loginUser.getUser().setSignature(sysUser.getSignature());
            tokenService.setLoginUser(loginUser);
        }
        return success(i);
    }

    @GetMapping("/getSignature")
    @ApiOperation("获取自己的签名")
    public AjaxResult getSignature() {
        SysUser sysUser = userService.selectUserById(SecurityUtils.getUserId());
        return AjaxResult.success("签名获取成功",sysUser);
    }

    /*@GetMapping("/xgmm")
    public AjaxResult updatePwd(){
        SysUser su=new SysUser();
        int i=0;
        List<SysUser> list= userService.selectUserList(su);
        for(SysUser u :list){
            if(StringUtils.isEmpty(u.getPassword())){
                String pstr="Gxsd#"+u.getUserName().substring(u.getUserName().length() - 4);
                u.setPassword(SecurityUtils.encryptPassword(pstr));
                i+= userService.resetPwd(u);//修改密码
            }
        }
        return  success(i);
    }*/

    @GetMapping("/xgmm")
    public AjaxResult updatePwd(){
        //SysUser su=new SysUser();
        int i=0;
        //su.setUserName("2023");
        SrsStuReg stuReg=new SrsStuReg();
        stuReg.setDelFlag("0");
        stuReg.setBJDM("1");
        List<SrsStuReg> list=iSrsStuRegService.selectSrsStuRegList(stuReg);
        //List<SysUser> list= userService.selectUserList(su);
        for(SrsStuReg u :list){
            //SysDept sd=deptService.selectDeptByDeptCode(stuReg.getXYDM());
            SysUser su=new SysUser();
            //su.setDeptId(sd.getDeptId());
            String pstr="Gxsd#"+u.getSFZH().substring(u.getSFZH().length() - 4);
            su.setCreateBy("admin");
            su.setPassword(SecurityUtils.encryptPassword(pstr));
            su.setUserName(u.getKSH());
            su.setPhonenumber(u.getSJH());
            su.setNickName(u.getXSXM());
            //su.setRoleId();
            String sexStr=u.getXB()=="男"?"0":"1";
            su.setSex(sexStr);
            userService.insertUser(su);
            i++;
        }
        return  success(i);
    }
}
