package com.srs.comprehensive.service;

import com.srs.common.core.domain.AjaxResult;
import com.srs.comprehensive.domain.Dto.CphExport;
import com.srs.comprehensive.domain.SrsCqScore;
import com.srs.comprehensive.domain.SrsMajors;
import com.srs.comprehensive.domain.Vo.*;
import org.springframework.data.repository.query.Param;

import java.util.List;
import java.util.Map;

/**
 * 学生综合素质评分表Service接口
 *
 * @author srs
 * @date 2023-06-29
 */
public interface ISrsCqScoreService
{
    /**
     * 查询学生综合素质评分表
     *
     * @param id 学生综合素质评分表主键
     * @return 学生综合素质评分表
     */
    public SrsCqScore selectSrsCqScoreById(Long id);

    public List<DataScreen> rankDis(CphSearch search);

    public List<DataScreen> countScoreDis(Long stuYearId);
    public List<DataScreen> countScoreDetailDis(Long stuYearId);

    public List<Map<String,Object>> exportScore(CphExport param);

    public List<CphStuScoreType> listOwnFive(String stuNo);

    public List<CphOwnScore> getOwn(String stuNo);

    public List<CphTotalScoreInfo> listCphScore(CphSearch search);

    public List<CphCollegeLook> listOwnCollegeScore(CphSearch param);
    public List<CphCollegeLook> listOwnCollegeStu(CphSearch param);
    public List<CphCollegeLook> listOwnCollegeAudit(CphSearch param);
    public List<SrsMajors> listOwnMajor(Long id);
    public List<SrsMajors> listOwnClass(CphSearch param);

//    /**
//     * 综合素质成绩汇总
//     * @param id 学年id
//     * @return
//     */
//    public  List<Map<String,Object>> getComprehensiveSummary(int id);

    /**
     * 生成综合素质成绩
     * @param id 学年id
     * @return 成功行数
     */
    public Map<String,Integer> generateComprehensiveSummary(int id);
    /**
     * 根据学生id查询综合成绩评分
     * @param
     * @return
     */
    List<SrsUserCqScore> selectSrsCqStuId();


    /**
     * 查询学生综合素质评分表列表
     * @param cphSearch 搜索实体类
     * @return 学生综合素质评分表集合
     */
    public List<SrsCqScore> selectSrsCqScoreList(CphSearch cphSearch);

    /**
     * 新增学生综合素质评分表
     *
     * @param srsCqScore 学生综合素质评分表
     * @return 结果
     */
    public int insertSrsCqScore(SrsCqScore srsCqScore);

    /**
     * 修改学生综合素质评分表
     *
     * @param srsCqScore 学生综合素质评分表
     * @return 结果
     */
    public int updateSrsCqScore(SrsCqScore srsCqScore);

    /**
     * 批量删除学生综合素质评分表
     *
     * @param ids 需要删除的学生综合素质评分表主键集合
     * @return 结果
     */
    public int deleteSrsCqScoreByIds(Long[] ids);

    /**
     * 删除学生综合素质评分表信息
     *
     * @param id 学生综合素质评分表主键
     * @return 结果
     */
    public int deleteSrsCqScoreById(Long id);

    AjaxResult getScoreDistribution(SrsCqScore srsCqScore);

    List<SrsCeScoreClassDeptGradeMajorsStudentStuYear> comprehensiveRanking(SrsCqScore srsCqScore);

}
