package com.srs.comprehensive.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.srs.common.core.domain.AjaxResult;
import com.srs.common.core.domain.entity.SysUser;
import com.srs.common.utils.DateUtils;
import com.srs.common.utils.StringUtils;
import com.srs.system.service.ISysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import com.srs.comprehensive.mapper.CphStuExtraInfoMapper;
import com.srs.comprehensive.domain.CphStuExtraInfo;
import com.srs.comprehensive.service.ICphStuExtraInfoService;

/**
 * 学生其他信息Service业务层处理
 *
 * @author srs
 * @date 2024-04-07
 */
@Service
public class CphStuExtraInfoServiceImpl extends ServiceImpl<CphStuExtraInfoMapper,CphStuExtraInfo> implements ICphStuExtraInfoService {
    @Autowired
    private CphStuExtraInfoMapper cphStuExtraInfoMapper;
    @Autowired
    private ISysUserService userService;

    @Override
    public AjaxResult submitOwnInfo(CphStuExtraInfo param){
        try{
            param.setKsh(null);
            QueryWrapper<CphStuExtraInfo> query = new QueryWrapper<>();
            query.eq("stu_no",param.getStuNo())
                    .last("limit 1");
            CphStuExtraInfo info = cphStuExtraInfoMapper.selectOne(query);
            if(info != null){
                param.setId(info.getId());
            }
            //如果上传了日常照片，就保存到用户头像
            if(StringUtils.isNotNull(param.getDailyPhoto())){
                userService.updateUserAvatar(param.getStuNo(),param.getDailyPhoto());
            }
            boolean res = this.saveOrUpdate(param);
            if(!res){
                throw new Exception("保存失败");
            }
            return AjaxResult.success();
        }catch (Exception ex){
            return AjaxResult.error(ex.getMessage());
        }
    }


    @Override
    public CphStuExtraInfo getStuInfo(String stuNo){
        QueryWrapper<CphStuExtraInfo> query = new QueryWrapper<>();
        query.eq("stu_no",stuNo)
                .last("limit 1");
        CphStuExtraInfo res = cphStuExtraInfoMapper.selectOne(query);
        return res;
    }


    /**
     * 查询学生其他信息
     *
     * @param id 学生其他信息主键
     * @return 学生其他信息
     */
    @Override
    public CphStuExtraInfo selectCphStuExtraInfoById(Long id) {
        return cphStuExtraInfoMapper.selectCphStuExtraInfoById(id);
    }

    /**
     * 查询学生其他信息列表
     *
     * @param cphStuExtraInfo 学生其他信息
     * @return 学生其他信息
     */
    @Override
    public List<CphStuExtraInfo> selectCphStuExtraInfoList(CphStuExtraInfo cphStuExtraInfo) {
        return cphStuExtraInfoMapper.selectCphStuExtraInfoList(cphStuExtraInfo);
    }

    /**
     * 新增学生其他信息
     *
     * @param cphStuExtraInfo 学生其他信息
     * @return 结果
     */
    @Override
    public int insertCphStuExtraInfo(CphStuExtraInfo cphStuExtraInfo) {
                cphStuExtraInfo.setCreateTime(DateUtils.getNowDate());
            return cphStuExtraInfoMapper.insertCphStuExtraInfo(cphStuExtraInfo);
    }

    /**
     * 修改学生其他信息
     *
     * @param cphStuExtraInfo 学生其他信息
     * @return 结果
     */
    @Override
    public int updateCphStuExtraInfo(CphStuExtraInfo cphStuExtraInfo) {
                cphStuExtraInfo.setUpdateTime(DateUtils.getNowDate());
        return cphStuExtraInfoMapper.updateCphStuExtraInfo(cphStuExtraInfo);
    }

    /**
     * 批量删除学生其他信息
     *
     * @param ids 需要删除的学生其他信息主键
     * @return 结果
     */
    @Override
    public int deleteCphStuExtraInfoByIds(Long[] ids) {
        return cphStuExtraInfoMapper.deleteCphStuExtraInfoByIds(ids);
    }

    /**
     * 删除学生其他信息信息
     *
     * @param id 学生其他信息主键
     * @return 结果
     */
    @Override
    public int deleteCphStuExtraInfoById(Long id) {
        return cphStuExtraInfoMapper.deleteCphStuExtraInfoById(id);
    }
}
