package com.srs.diagnostic.mapper;

import java.util.List;

import com.srs.diagnostic.domain.DiaReportItems;
import com.srs.diagnostic.domain.DiaReports;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import io.lettuce.core.dynamic.annotation.Param;

/**
 * 诊断报告基础信息Mapper接口
 *
 * @author srs
 * @date 2025-03-21
 */
public interface DiaReportsMapper extends BaseMapper<DiaReports> {
    /**
     * 查询诊断报告基础信息
     *
     * @param reportId 诊断报告基础信息主键
     * @return 诊断报告基础信息
     */
    public DiaReports selectDiaReportsByReportId(int reportId);

    /**
     * 查询诊断报告基础信息列表
     *
     * @param diaReports 诊断报告基础信息
     * @return 诊断报告基础信息集合
     */
    List<DiaReports> selectDiaReportsList(DiaReports diaReports);
    List<DiaReports> getNameList(DiaReports diaReports);
    List<DiaReports> xlkList( );
    /**
     * 新增诊断报告基础信息
     *
     * @param diaReports 诊断报告基础信息
     * @return 结果
     */
    int insertDiaReports(DiaReports diaReports);

    /**
     * 修改诊断报告基础信息
     *
     * @param diaReports 诊断报告基础信息
     * @return 结果
     */
    int updateDiaReports(DiaReports diaReports);

    /**
     * 删除诊断报告基础信息
     *
     * @param reportId 诊断报告基础信息主键
     * @return 结果
     */
    int deleteDiaReportsByReportId(int reportId);

    /**
     * 批量删除诊断报告基础信息
     *
     * @param reportIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteDiaReportsByReportIds(int[] reportIds);
    int insertReportItem(DiaReportItems diaReportItems);
    List<DiaReports> getAllReports();
    /**
     * 查询所有报告数据
     */
    List<DiaReports> selectAllReports(int curReportId);

    /**
     * 根据父ID查询子报告
     */
    List<DiaReports> selectChildrenByParentId(@Param("parentId") Integer parentId);
    DiaReports selectParentById(int reportId);
}
