package com.srs.diagnostic.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import com.srs.diagnostic.mapper.DiaEligibilityMapper;
import com.srs.diagnostic.domain.DiaEligibility;
import com.srs.diagnostic.service.IDiaEligibilityService;

/**
 * 合格标准Service业务层处理
 *
 * @author srs
 * @date 2025-03-25
 */
@Service
public class DiaEligibilityServiceImpl extends ServiceImpl<DiaEligibilityMapper,DiaEligibility> implements IDiaEligibilityService {
    @Autowired
    private DiaEligibilityMapper diaEligibilityMapper;

    /**
     * 查询合格标准
     *
     * @param eliId 合格标准主键
     * @return 合格标准
     */
    @Override
    public DiaEligibility selectDiaEligibilityByEliId(Long eliId) {
        return diaEligibilityMapper.selectDiaEligibilityByEliId(eliId);
    }

    /**
     * 查询合格标准列表
     *
     * @param diaEligibility 合格标准
     * @return 合格标准
     */
    @Override
    public List<DiaEligibility> selectDiaEligibilityList(DiaEligibility diaEligibility) {
        return diaEligibilityMapper.selectDiaEligibilityList(diaEligibility);
    }

    /**
     * 新增合格标准
     *
     * @param diaEligibility 合格标准
     * @return 结果
     */
    @Override
    public int insertDiaEligibility(DiaEligibility diaEligibility) {
            return diaEligibilityMapper.insertDiaEligibility(diaEligibility);
    }

    /**
     * 修改合格标准
     *
     * @param diaEligibility 合格标准
     * @return 结果
     */
    @Override
    public int updateDiaEligibility(DiaEligibility diaEligibility) {
        return diaEligibilityMapper.updateDiaEligibility(diaEligibility);
    }

    /**
     * 批量删除合格标准
     *
     * @param eliIds 需要删除的合格标准主键
     * @return 结果
     */
    @Override
    public int deleteDiaEligibilityByEliIds(Long[] eliIds) {
        return diaEligibilityMapper.deleteDiaEligibilityByEliIds(eliIds);
    }

    /**
     * 删除合格标准信息
     *
     * @param eliId 合格标准主键
     * @return 结果
     */
    @Override
    public int deleteDiaEligibilityByEliId(Long eliId) {
        return diaEligibilityMapper.deleteDiaEligibilityByEliId(eliId);
    }
}
