package com.srs.flowable.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.srs.common.annotation.Excel;
import com.srs.common.core.domain.BaseEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.*;

import java.util.Date;


/**
 * 学生处分申请对象 rt_stu_disciplinary_application
 *
 * @author LSD
 * @date 2024-04-17
 */
@Data
@EqualsAndHashCode(callSuper = true)
@NoArgsConstructor
@AllArgsConstructor
@Builder
@ApiModel(value = "RtStuDisciplinaryApplication对象", description = "学生处分申请表")
@TableName("rt_stu_disciplinary_application")
public class StuDisciplinaryApplication extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 申请ID
     */
    @ApiModelProperty("申请ID")
    @TableField("application_id")
    private Long applicationId;

    /**
     * 辅导员id
     */
    @ApiModelProperty("辅导员id")
    @TableField("applicant_id")
    @Excel(name = "辅导员id")
    private Long applicantId;

    /**
     * 处分文号
     */
    @ApiModelProperty("处分文号")
    @TableField("penalty_number")
    @Excel(name = "处分文号")
    private String penaltyNumber;

    /**
     * 学号
     */
    @ApiModelProperty("学号")
    @TableField("stu_no")
    @Excel(name = "学号")
    private String stuNo;

    /**
     * 学生用户ID,sys_user的id
     */
    @ApiModelProperty("学生用户ID,sys_user的id")
    @TableField("stu_id")
    @Excel(name = "学生用户ID,sys_user的id")
    private Long stuId;

    /**
     * 处分等级：（0-警告；1-严重警告；2-记过；3-留校察看）
     */
    @ApiModelProperty("处分等级：（0-警告；1-严重警告；2-记过；3-留校察看）")
    @TableField("penalty_type")
    @Excel(name = "处分等级：", readConverterExp = "0=-警告；1-严重警告；2-记过；3-留校察看;4-开出学籍")
    private Long penaltyType;

    /**
     * 处分状态（0-处分中；1-处分解除；2-解除申请中）
     */
    @ApiModelProperty("处分状态（0-处分中；1-处分解除；2-解除申请中）")
    @TableField("penalty_status")
    @Excel(name = "处分状态", readConverterExp = "0=-处分中；1-处分解除；2-解除申请中")
    private Long penaltyStatus;

    /**
     * 违纪日期
     */
    @ApiModelProperty("违纪日期")
    @TableField("violation_date")
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "违纪日期", width = 30, dateFormat = "yyyy-MM-dd")
    private Date violationDate;

    /**
     * 处分到期时间
     */
    @ApiModelProperty("处分到期时间")
    @TableField("expiration_date")
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "处分到期时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date expirationDate;

    /**
     * 证据上传,多个逗号隔开
     */
    @ApiModelProperty("证据上传,多个逗号隔开")
    @TableField("evidence_upload")
    @Excel(name = "证据上传,多个逗号隔开")
    private String evidenceUpload;

    /**
     * 处分建议
     */
    @ApiModelProperty("处分建议")
    @TableField("penalty_recommendation")
    @Excel(name = "处分建议")
    private String penaltyRecommendation;

    /**
     * 违规条例
     */
    @ApiModelProperty("违规条例")
    @TableField("violation_regulations")
    @Excel(name = "违规条例")
    private String violationRegulations;

    /**
     * 提交状态（0-保存；1-提交）
     */
    @ApiModelProperty("提交状态（0-保存；1-提交）")
    @TableField("submission_status")
    @Excel(name = "提交状态", readConverterExp = "0=-保存；1-提交")
    private Long submissionStatus;

    /**
     * 流程实例ID
     */
    @ApiModelProperty("流程实例ID")
    @TableField("process_instance_id")
    @Excel(name = "流程实例ID")
    private String processInstanceId;

    @ApiModelProperty("流程部署编号")
    @TableField("deploy_id")
    @Excel(name = "流程实例ID")
    private String deployId;

    @ApiModelProperty("辅导员姓名")
    @TableField("applicant_name")
    @Excel(name = "辅导员姓名")
    private String applicantName;

    @ApiModelProperty("学生姓名")
    @TableField("stu_name")
    @Excel(name = "学生姓名")
    private String stuName;

    /**
     * 性别
     */
    @ApiModelProperty("性别")
    @TableField("gender")
    @Excel(name = "性别")
    private String gender;

    /**
     * 部门
     */
    @ApiModelProperty("部门")
    @TableField("department_Name")
    @Excel(name = "部门")
    private String departmentName;

    /**
     * 年级
     */
    @ApiModelProperty("年级")
    @TableField("grade_name")
    @Excel(name = "年级")
    private String gradeName;

    /**
     * 班级
     */
    @ApiModelProperty("班级")
    @TableField("class_name")
    @Excel(name = "班级")
    private String className;

    /**
     * 民族
     */
    @ApiModelProperty("民族")
    @TableField("mz")
    @Excel(name = "民族")
    private String mz;

    /**
     * 出生日期
     */
    @ApiModelProperty("出生日期")
    @TableField("birthday")
    @Excel(name = "出生日期")
    private String birthday;

    /**
     * 籍贯
     */
    @ApiModelProperty("籍贯")
    @TableField("jg")
    @Excel(name = "籍贯")
    private String jg;

    /**
     * 市/县
     */
    @ApiModelProperty("市/县")
    @TableField("hksz2")
    @Excel(name = "市/县")
    private String hksz2;

    @ApiModelProperty("处分下文")
    @TableField("disposition_service")
    @Excel(name = "处分下文")
    private String dispositionService;


    @ApiModelProperty("送达书")
    @TableField("letter_service")
    @Excel(name = "送达书")
    private String letterService;
}
