package com.srs.routine.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.routine.domain.RtStuDisciplinaryRelieve;

/**
 * 学生解除处分申请Service接口
 *
 * @author LSD
 * @date 2024-04-29
 */
public interface IRtStuDisciplinaryRelieveService extends IService<RtStuDisciplinaryRelieve> {
    /**
     * 查询学生解除处分申请
     *
     * @param relieveId 学生解除处分申请主键
     * @return 学生解除处分申请
     */
    public RtStuDisciplinaryRelieve selectRtStuDisciplinaryRelieveByRelieveId(Long relieveId);

    /**
     * 查询学生解除处分申请列表
     *
     * @param rtStuDisciplinaryRelieve 学生解除处分申请
     * @return 学生解除处分申请集合
     */
    List<RtStuDisciplinaryRelieve> selectRtStuDisciplinaryRelieveList(RtStuDisciplinaryRelieve rtStuDisciplinaryRelieve);

    /**
     * 新增学生解除处分申请
     *
     * @param rtStuDisciplinaryRelieve 学生解除处分申请
     * @return 结果
     */
    int insertRtStuDisciplinaryRelieve(RtStuDisciplinaryRelieve rtStuDisciplinaryRelieve);


    /**
     * 修改
     * @param rtStuDisciplinaryRelieve
     * @return
     */
    int editRtStuDisciplinaryRelieve(RtStuDisciplinaryRelieve rtStuDisciplinaryRelieve);

    /**
     * 修改学生解除处分申请
     *
     * @param rtStuDisciplinaryRelieve 学生解除处分申请
     * @return 结果
     */
    int updateRtStuDisciplinaryRelieve(RtStuDisciplinaryRelieve rtStuDisciplinaryRelieve);

    /**
     * 批量删除学生解除处分申请
     *
     * @param relieveIds 需要删除的学生解除处分申请主键集合
     * @return 结果
     */
    int deleteRtStuDisciplinaryRelieveByRelieveIds(Long[] relieveIds);

    /**
     * 删除学生解除处分申请信息
     *
     * @param relieveId 学生解除处分申请主键
     * @return 结果
     */
    int deleteRtStuDisciplinaryRelieveByRelieveId(Long relieveId);

    /**
     * 根据流程id获取解除处分单
     * @param procInsId
     * @return
     */
    RtStuDisciplinaryRelieve getDisciplinaryRelieveByProcInsId(String procInsId);

    /**
     * 获取学生本人处分信息
     * @param rtStuDisciplinaryRelieve
     * @return
     */
    List<RtStuDisciplinaryRelieve> getRtStuDisciplinaryRelieveListByStuNo(RtStuDisciplinaryRelieve rtStuDisciplinaryRelieve);

    /**
     * 根据辅导员工号，查询辅导员所负责的班级的处分申请信息
     * @param rtStuDisciplinaryRelieve
     * @return
     */
    List<RtStuDisciplinaryRelieve> getRtStuDisciplinaryRelieveListByTeacherNo(RtStuDisciplinaryRelieve rtStuDisciplinaryRelieve);

    /**
     * 学务查询
     * @param rtStuDisciplinaryRelieve
     * @return
     */
    List<RtStuDisciplinaryRelieve> selectRtStuDisciplinaryRelieveListByXW(RtStuDisciplinaryRelieve rtStuDisciplinaryRelieve);
}
