package com.srs.staff.domain;

import java.util.Date;
import java.util.List;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.srs.common.annotation.Excel;
import com.baomidou.mybatisplus.annotation.*;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.*;
import com.srs.common.core.domain.BaseEntity;


/**
 * 一站式社区模块：社区建设对象 srs_staff_one_stop_community_construction
 *
 * @author chc
 * @date 2024-07-17
 */
@Data
@EqualsAndHashCode(callSuper = true)
@NoArgsConstructor
@AllArgsConstructor
@Builder
@ApiModel(value = "SrsStaffOneStopCommunityConstruction对象", description = "一站式社区模块：社区建设")
@TableName("srs_staff_one_stop_community_construction")
public class SrsStaffOneStopCommunityConstruction extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 社区建设记录id
     */
    @ApiModelProperty("社区建设记录id")
    @TableField("construct_id")
    private Long constructId;

    // 用户选择某条数据的id列表 （导出）
    private List<Long> ids;

    // 查询数据按时间查询（开始时间）
    private Date startTime;

    // 查询数据按时间查询（结束时间）
    private Date endTime;

    /**
     * 活动主题
     */
    @ApiModelProperty("活动主题")
    @TableField("activity_theme")
    @Excel(name = "活动主题")
    private String activityTheme;

    /**
     * 活动概况
     */
    @ApiModelProperty("活动概况")
    @TableField("activity_profile")
    @Excel(name = "活动概况")
    private String activityProfile;

    /**
     * 参与人员类型
     */
    @ApiModelProperty("参与人员类型")
    @TableField("personnel_type")
    @Excel(name = "参与人员类型")
    private String personnelType;

    /**
     * 主要参加人员名单
     */
    @ApiModelProperty("主要参加人员名单")
    @TableField("personnel_list")
    @Excel(name = "主要参加人员名单")
    private String personnelList;

    /**
     * 时间
     */
    @ApiModelProperty("时间")
    @TableField("construct_time")
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date constructTime;

    /**
     * 地点
     */
    @ApiModelProperty("地点")
    @TableField("place")
    @Excel(name = "地点")
    private String place;

    /**
     * 服务学生人次
     */
    @ApiModelProperty("服务学生人次")
    @TableField("stu_number")
    @Excel(name = "服务学生人次")
    private Long stuNumber;

    /**
     * 活动照片
     */
    @ApiModelProperty("活动照片")
    @TableField("activity_photo")
    @Excel(name = "活动照片")
    private String activityPhoto;

    /**
     * 审核状态
     */
    @ApiModelProperty("审核状态")
    @TableField("audit_status")
    @Excel(name = "审核状态")
    private Long auditStatus;

    /**
     * 修改意见
     */
    @ApiModelProperty("修改意见")
    @TableField("edit_opinion")
    @Excel(name = "修改意见")
    private String editOpinion;

    /**
     * 活动发起人
     */
    @ApiModelProperty("活动发起人")
    @TableField("event_promoter")
    @Excel(name = "活动发起人")
    private String eventPromoter;

    //user_name
    @ApiModelProperty("活动发起人学号或工号")
    @TableField("user_name")
    @Excel(name = "活动发起人学号/工号")
    private String userName;

    /**
     * 活动图片
     */
    @ApiModelProperty(value = "活动压缩文件")
    @TableField("active_package")
    @Excel(name = "活动压缩文件")
    private String activePackage;
}
