package com.srs.system.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.system.domain.SysDeptMap;

/**
 * 部门映射Service接口
 *
 * @author srs
 * @date 2024-05-13
 */
public interface ISysDeptMapService extends IService<SysDeptMap> {

    /**
     * 通过行政架构的部门id查询行政班级架构下的部门 oldDeptId表示行政班级架构下的id newDeptId表示行政架构下的id
     * @author zhy
     * @date 2024-05-13 16:01:35
     * @param id
     * @return
     **/
    public SysDeptMap getOldDeptByNewId(Long id);

    /**
     * 通过行政班级架构的部门id查询行政架构下的部门
     * @param id
     * @return
     */
    public SysDeptMap getNewDeptByOldId(Long id);

    /**
     * 查询部门映射
     *
     * @param id 部门映射主键
     * @return 部门映射
     */
    public SysDeptMap selectSysDeptMapById(Long id);

    /**
     * 查询部门映射列表
     *
     * @param sysDeptMap 部门映射
     * @return 部门映射集合
     */
    List<SysDeptMap> selectSysDeptMapList(SysDeptMap sysDeptMap);

    /**
     * 新增部门映射
     *
     * @param sysDeptMap 部门映射
     * @return 结果
     */
    int insertSysDeptMap(SysDeptMap sysDeptMap);

    /**
     * 修改部门映射
     *
     * @param sysDeptMap 部门映射
     * @return 结果
     */
    int updateSysDeptMap(SysDeptMap sysDeptMap);

    /**
     * 批量删除部门映射
     *
     * @param ids 需要删除的部门映射主键集合
     * @return 结果
     */
    int deleteSysDeptMapByIds(Long[] ids);

    /**
     * 删除部门映射信息
     *
     * @param id 部门映射主键
     * @return 结果
     */
    int deleteSysDeptMapById(Long id);
}
